@@ -83,15 +83,10 @@ class ScaleDownAction(templates.ProcessTemplatesAction):
         fields = processed_data.copy()
         fields['timeout_mins'] = timeout_mins
         fields['existing'] = True
-        # As we do a PATCH update when deleting nodes, parameters set for a
-        # stack before upgrade to newton (ex. ComputeRemovalPolicies),
-        # would still take precedence over the ones set in parameter_defaults
-        # after upgrade. Clear these parameters for backward compatibility.
-        fields['clear_parameters'] = list(parameters.keys())
 
         LOG.debug('stack update params: %s', fields)
-        self._get_orchestration_client().stacks.update(self.container,
-                                                       **fields)
+        self.get_orchestration_client().stacks.update(self.container,
+                                                      **fields)
 
     def _get_removal_params_from_heat(self, resources_by_role, resources):
         stack_params = {}
@@ -116,7 +111,7 @@ class ScaleDownAction(templates.ProcessTemplatesAction):
         return stack_params
 
     def run(self):
-        heatclient = self._get_orchestration_client()
+        heatclient = self.get_orchestration_client()
         resources = heatclient.resources.list(self.container, nested_depth=5)
         resources_by_role = collections.defaultdict(list)
         instance_list = list(self.nodes)
